# Viewpoint

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**index** | **int** |  | [optional] 
**guid** | **str** |  | [optional] 
**orthogonal_camera** | [**OrthogonalCamera**](OrthogonalCamera.md) |  | [optional] 
**perspective_camera** | [**PerspectiveCamera**](PerspectiveCamera.md) |  | [optional] 
**lines** | [**list[Line]**](Line.md) |  | [optional] 
**clipping_planes** | [**list[ClippingPlane]**](ClippingPlane.md) |  | [optional] 
**snapshot** | [**Snapshot**](Snapshot.md) |  | [optional] 
**components** | [**ComponentsParent**](ComponentsParent.md) |  | [optional] 
**temp_id** | **int** | Only used when using POST on the full-topic route to bind viewpoint with comment | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


